# SPDX-FileCopyrightText: Emery Hemingway
#
# SPDX-License-Identifier: LicenseRef-Hippocratic-1.1

{ system ? "x86_64-genode", nixpkgs ? import <nixpkgs>, extraOverlays ? [ ] }:

let
  toolchainOverlay = import ./toolchain-overlay;
  # Overlay of toolchain patches

  super = nixpkgs {
    # Evaluate an overlayed Nixpkgs for a Genode target
    localSystem = "x86_64-linux";
    crossSystem = "x86_64-genode";
    overlays = [ toolchainOverlay ] ++ extraOverlays;
  };

  inherit (super) callPackage;

  genode = (callPackage ./upstream { } // {
    libc = callPackage ./pkgs/libc { };
    nic_bus = callPackage ./pkgs/nic_bus { };
  });
  dhallPackages = super.dhallPackages // (callPackage ./dhall { });
in rec {
  inherit (super) stdenv;
  genode-base = genode.base;
  genode-base-linux = genode.base-linux;
  genode-base-nova = genode.base-nova;
  genode-os = genode.os;

  dhallGenode = dhallPackages.genode;
  dhallPrelude = dhallPackages.prelude;
  nova = callPackage ./NOVA { };
  solo5 = callPackage ./pkgs/solo5 { inherit genode-base genode-os; };
}
